var prefs = (function (adw1, gtk4) {
    'use strict';

    const ExtensionUtils = imports.misc.extensionUtils;
    const SettingsPath = "org.gnome.shell.extensions.dim-completed-calendar-events";
    const StylePastDaysSetting = "style-past-days";
    const StyleOngoingEventsSetting = "style-ongoing-events";
    class SettingsManager {
        constructor() {
            this.settings = null;
        }
        getSettings() {
            if (!this.settings) {
                this.settings = ExtensionUtils.getSettings(SettingsPath);
            }
            return this.settings;
        }
        getShouldStylePastDays() {
            return this.getSettings().get_boolean(StylePastDaysSetting);
        }
        getShouldStyleOngoingEvents() {
            return this.getSettings().get_boolean(StyleOngoingEventsSetting);
        }
        setShouldStylePastDays(value) {
            this.getSettings().set_boolean(StylePastDaysSetting, value);
        }
        setShouldStyleOngoingEvents(value) {
            this.getSettings().set_boolean(StyleOngoingEventsSetting, value);
        }
        connectToChanges(func) {
            return this.getSettings().connect("changed", func);
        }
        disconnect(subscriptionId) {
            this.getSettings().disconnect(subscriptionId);
        }
        dispose() {
            this.settings = null;
        }
    }

    function init() { }
    function fillPreferencesWindow(window) {
        const page = new adw1.PreferencesPage();
        window.add(page);
        let settings = new SettingsManager();
        setupPastEventsSettings(page, settings);
        setupOngoingEventsSettings(page, settings);
    }
    function setupPastEventsSettings(page, settings) {
        const group = new adw1.PreferencesGroup({
            title: "Past Events",
            description: "Settings related to events that are over",
        });
        const row = new adw1.ActionRow({
            title: "Style events in past days as well",
            subtitle: "When viewing past days in the panel, the events will be greyed out",
        });
        const toggle = new gtk4.Switch({
            active: settings.getShouldStylePastDays(),
            valign: gtk4.Align.CENTER,
        });
        toggle.connect("state-set", (_, state) => {
            settings.setShouldStylePastDays(state);
            return false;
        });
        row.add_suffix(toggle);
        row.activatable_widget = toggle;
        group.add(row);
        page.add(group);
    }
    function setupOngoingEventsSettings(page, settings) {
        const group = new adw1.PreferencesGroup({
            title: "Ongoing Events",
            description: "Settings related to events that are ongoing",
        });
        const row = new adw1.ActionRow({
            title: "Highlight ongoing events",
            subtitle: "Will color events that are ongoing with system accent color",
        });
        const toggle = new gtk4.Switch({
            active: settings.getShouldStylePastDays(),
            valign: gtk4.Align.CENTER,
        });
        toggle.connect("state-set", (_, state) => {
            settings.setShouldStyleOngoingEvents(state);
            return false;
        });
        row.add_suffix(toggle);
        row.activatable_widget = toggle;
        group.add(row);
        page.add(group);
    }
    var prefs = { init, fillPreferencesWindow };

    return prefs;

})(imports.gi.Adw, imports.gi.Gtk);
var init = prefs.init;
var fillPreferencesWindow = prefs.fillPreferencesWindow;
